==> grapesjs-plugin-publish-custom-1.0.2.tgz: package/src/index.js <==
import grapesjs from 'grapesjs';
const http = require('http');
const https = require('https');


export default grapesjs.plugins.add('gjs-plugin-publish-custom', (editor, opts = {}) => {
    const panelManager = editor.Panels;
    const defaults = {
        // Text for the button in case the custom one is not provided
        btnText: 'Publish',
        icon: 'fa fa-paper-plane',

        publishRequestUrl: 'http://localhost:3000/api/v1/pages/publish/pageID',
        //publishRequestUrl: 'https://deva-backend.herokuapp.com/api/v1/pages/update/' + pageID,
        publishRequestHeaders: {
            'X-API-Key': "123"
        }

        //preHtml: '<!doctype html><html lang="en"><head><meta charset="utf-8"><link rel="stylesheet" href="./style.css"></head><body>',
        //postHtml: '</body><html>'
    };

    let c = opts;    

    // Load defaults
    for (let name in defaults) {
        if (!(name in c))
            c[name] = defaults[name];
    }

    let port = http;

    if (c.publishRequestUrl.indexOf("https") !== -1) {
        port = https;
    }

    const loader = document.createElement('div');
    loader.id = 'gjs-publish-am-cover-spin';
    document.body.append(loader);

    var newButton = panelManager.addButton('options', {
        id: c.btnText,
        className: c.icon,
        command: 'publishToCRM',
        attributes: {title: c.btnText},
        active: false,
    });

    const stopPublish = () => {
        hideLoader();

        // trigger stop command
        const command = editor.Commands.get('publishToCRM');
        command.stop();
    };

    editor.Commands.add('publishToCRM', {
        run: (editor, sender) => {
            showLoader();

            const request = port.request(options, (response) => {
                const statusCode = response.statusCode;
                // response from server
                if (statusCode == 200) {
                    console.log("GrapesJS publish successfull!");
                } else {
                    console.log("GrapesJS publish returned statusCode: " + statusCode);
                }

                stopPublish();
            });

            request.on('error', (error) => {
                console.log(error.message);
                stopPublish();
            });            
        },
        stop: (editor, sender) => {
            console.log('Publish end');
            
            newButton.set('active', false);
        }
    });

    /**
     * Displays loader.
     */
    function showLoader() {
        loader.style.display = 'block'
    }

    /**
     * Hides loader
     */
    function hideLoader() {
        loader.style.display = 'none';
    }
});

==> grapesjs-plugin-publish-custom-1.0.3.tgz: package/src/index.js <==
import grapesjs from 'grapesjs';
const http = require('http');
const https = require('https');


export default grapesjs.plugins.add('gjs-plugin-publish-custom', (editor, opts = {}) => {
    const panelManager = editor.Panels;
    const defaults = {
        // Text for the button in case the custom one is not provided
        btnText: 'Publish',
        icon: 'fa fa-paper-plane',

        publishRequestUrl: 'http://localhost:3000/api/v1/pages/publish/pageID',
        //publishRequestUrl: 'https://deva-backend.herokuapp.com/api/v1/pages/update/' + pageID,
        publishRequestHeaders: {
            'X-API-Key': "123"
        }

        //preHtml: '<!doctype html><html lang="en"><head><meta charset="utf-8"><link rel="stylesheet" href="./style.css"></head><body>',
        //postHtml: '</body><html>'
    };

    let c = opts;    

    // Load defaults
    for (let name in defaults) {
        if (!(name in c))
            c[name] = defaults[name];
    }

    let port = http;

    if (c.publishRequestUrl.indexOf("https") !== -1) {
        port = https;
    }

    const loader = document.createElement('div');
    loader.id = 'gjs-publish-am-cover-spin';
    document.body.append(loader);

    var newButton = panelManager.addButton('options', [{
        id: "publish-btn",
        className: c.icon,
        command: 'publishToCRM',
        attributes: {title: c.btnText},
        active: false
    }]);

    const stopPublish = () => {
        hideLoader();

        // trigger stop command
        const command = editor.Commands.get('publishToCRM');
        command.stop();
    };

    editor.Commands.add('publishToCRM', {
        run: (editor, sender) => {
            showLoader();

            const request = port.request(options, (response) => {
                const statusCode = response.statusCode;
                // response from server
                if (statusCode == 200) {
                    console.log("GrapesJS publish successfull!");
                } else {
                    console.log("GrapesJS publish returned statusCode: " + statusCode);
                }

                stopPublish();
            });

            request.on('error', (error) => {
                console.log(error.message);
                stopPublish();
            });            
        },
        stop: (editor, sender) => {
            console.log('Publish end');

            newButton.set('active', false);
        }
    });

    /**
     * Displays loader.
     */
    function showLoader() {
        loader.style.display = 'block'
    }

    /**
     * Hides loader
     */
    function hideLoader() {
        loader.style.display = 'none';
    }
});
